@@ -71,21 +71,23 @@ class OneByOne(nn.Module):
         else:
             loss_tensors = torch.as_tensor(targets).to(self.device)
             negativeloss_tensors = torch.as_tensor(negative_targets).to(self.device)
-            loss_fct = nn.CrossEntropyLoss(reduction='none', ignore_index=-1)  # -1 index = padding token
+            # loss_fct = nn.CrossEntropyLoss(reduction='none', ignore_index=-1)  # -1 index = padding token
+            loss_fct = nn.CrossEntropyLoss(ignore_index=-1)  # -1 index = padding token
             masked_lm_loss = loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
                                       loss_tensors.view(-1))
 
-            negative_loss_fct = NegativeCElLoss(reduction='none', ignore_index=-1).to(self.device)
+            # negative_loss_fct = NegativeCElLoss(reduction='none', ignore_index=-1).to(self.device)
+            negative_loss_fct = NegativeCElLoss(ignore_index=-1).to(self.device)
             negative_loss = negative_loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
                                               negativeloss_tensors.view(-1))
 
             masked_lm_loss += negative_loss
-            masked_lm_loss = masked_lm_loss.view(-1, len(targets))  # view by batch size
-            masked_lm_loss = masked_lm_loss.sum(dim=0)
-            if self.lossdrop:
-                mask = self.dropper(masked_lm_loss)
-                masked_lm_loss *= mask
-            masked_lm_loss = masked_lm_loss.mean()
+            # masked_lm_loss = masked_lm_loss.view(-1, len(targets))  # view by batch size
+            # masked_lm_loss = masked_lm_loss.sum(dim=0)
+            # if self.lossdrop:
+            #     mask = self.dropper(masked_lm_loss)
+            #     masked_lm_loss *= mask
+            # masked_lm_loss = masked_lm_loss.mean()
             outputs = masked_lm_loss
         return outputs
 
